@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -71,7 +71,7 @@ add a new task to scheduler task list
                                                             #   provided) that can exists at the same
                                                             #   time, value of 0 means unlimited
         Data => {                                           # data payload
-            ...
+            # ...
         },
     );
 
@@ -880,7 +880,7 @@ add a new task to scheduler future task list
                                                          #   that can exists at the same time,
                                                          #   value of 0 means unlimited
         Data => {                                        # data payload
-            ...
+            # ...
         },
     );
 
@@ -1557,7 +1557,7 @@ sub CronTaskSummary {
         next JOBNAME if !$JobConfig;
         next JOBNAME if !$JobConfig->{Schedule};
 
-        $TaskLookup{$JobName} = $JobConfig->{Schedule};
+        $TaskLookup{ $Config->{$JobName}->{TaskName} } = $JobConfig->{Schedule};
     }
 
     return $Self->RecurrentTaskSummary(
@@ -1810,9 +1810,9 @@ Returns:
         Type              => 'GenericInterface',
         LastExecutionTime => '2015-01-01 00:00:00',
         LockKey           => 'XYZ',
-        LockTime          => '2015-01-02 00:00:00'
-        CreateTime        => '2015-01-01 00:00:00'
-        ChangeTime        => '2015-01-02 00:00:00'
+        LockTime          => '2015-01-02 00:00:00',
+        CreateTime        => '2015-01-01 00:00:00',
+        ChangeTime        => '2015-01-02 00:00:00',
     );
 
 =cut
@@ -1875,9 +1875,9 @@ Returns:
             Type              => 'GenericInterface',
             LastExecutionTime => '2015-01-01 00:00:00',
             LockKey           => 'XYZ',
-            LockTime          => '2015-01-02 00:00:00'
-            CreateTime        => '2015-01-01 00:00:00'
-            ChangeTime        => '2015-01-02 00:00:00'
+            LockTime          => '2015-01-02 00:00:00',
+            CreateTime        => '2015-01-01 00:00:00',
+            ChangeTime        => '2015-01-02 00:00:00',
         },
         {
             TaskID            => 456,
@@ -1885,9 +1885,9 @@ Returns:
             Type              => 'GenericInterface',
             LastExecutionTime => '2015-01-01 00:00:00',
             LockKey           => 'XYZ',
-            LockTime          => '2015-01-02 00:00:00'
-            CreateTime        => '2015-01-01 00:00:00'
-            ChangeTime        => '2015-01-02 00:00:00'
+            LockTime          => '2015-01-02 00:00:00',
+            CreateTime        => '2015-01-01 00:00:00',
+            ChangeTime        => '2015-01-02 00:00:00',
         },
         # ...
     );
@@ -2002,7 +2002,7 @@ executes recurrent tasks like cron or generic agent tasks
                                                        #    table at the same time, value of 0 means
                                                        #    unlimited
         Data                   => {                    # data payload
-            ...
+            # ...
         },
     );
 
@@ -2275,9 +2275,9 @@ sub RecurrentTaskSummary {
         push @List, {
             Name                  => $Row[1],
             Type                  => $Row[2],
-            LastExecutionTime     => $Row[3] // '',
-            NextExecutionTime     => $NextExecutionTime // '',
-            LastWorkerStatus      => $LastWorkerStatus // 'N/A',
+            LastExecutionTime     => $Row[3]                // '',
+            NextExecutionTime     => $NextExecutionTime     // '',
+            LastWorkerStatus      => $LastWorkerStatus      // 'N/A',
             LastWorkerRunningTime => $LastWorkerRunningTime // 'N/A',
         };
     }
