@@ -276,6 +276,7 @@ Znuny.Form.Input = (function (TargetNS) {
         var Type;
         var Value;
         var $Element;
+        var CKEditorObj;
 
         Options = Options || {};
 
@@ -293,11 +294,11 @@ Znuny.Form.Input = (function (TargetNS) {
         }
 
         if (FieldID === 'RichText' || Type === 'RichText') {
+            CKEditorObj = Core.UI.RichTextEditor.GetInstance(FieldID);
             if (
-                typeof CKEDITOR !== 'undefined'
-                && CKEDITOR.instances[FieldID]
+                CKEditorObj !== undefined
             ) {
-                return CKEDITOR.instances[FieldID].getData();
+                return CKEditorObj.getData();
             }
             else {
                 return $('#'+ FieldID).val();
@@ -566,7 +567,8 @@ Znuny.Form.Input = (function (TargetNS) {
             TriggerChange,
             Type,
             SetAsTicketCustomer,
-            Modernize;
+            Modernize,
+            CKEditorObj;
 
         Options = Options || {};
 
@@ -595,14 +597,14 @@ Znuny.Form.Input = (function (TargetNS) {
         }
 
         if (FieldID === 'RichText' || Type == 'RichText') {
+            CKEditorObj = Core.UI.RichTextEditor.GetInstance(FieldID);
             if (
-                typeof CKEDITOR !== 'undefined'
-                && CKEDITOR.instances[FieldID]
+                CKEditorObj !== undefined
             ) {
                 // Attention: No 'change' event will get triggered
                 // and the content will get re-rendered, so all events are lost :)
                 // See: https://dev.ckeditor.com/ticket/6633
-                CKEDITOR.instances[FieldID].setData(Content || '');
+                CKEditorObj.setData(Content || '');
                 Core.App.Publish('Znuny.Form.Input.Change.'+ Attribute);
             }
             else {
@@ -1304,22 +1306,18 @@ Znuny.Form.Input = (function (TargetNS) {
 
         Result = true
     */
+    // TODO: check if this is needed at all
+    // TODO: probably to migrate in it's own way
     TargetNS.RichTextConfig = function (NewConfig) {
-        if (typeof CKEDITOR === 'undefined') {
+        if (typeof ZnunyEditor === 'undefined') {
             return;
         }
 
         // remove all rte's
         $('textarea.RichText').each(function () {
             var EditorID = $(this).attr('id');
-            var Editor   = CKEDITOR.instances[EditorID];
-
-            if (!Editor) return true;
-
-            $(this).removeClass('HasCKEInstance');
-            Editor.destroy(true);
+            Core.UI.RichTextEditor.DestroyInstance(EditorID)
         });
-
         // add hack to overwrite config at its lowest place
         CKEDITOR.replaceZnunyFormInput = CKEDITOR.replace;
         CKEDITOR.replace = function(EditorID, EditorConfig) {
